import chalk from 'chalk'
import { stackParser } from '../stackparser.js'

const linereporter = () => {
  const lines = []

  const report = {
    start: (title) => {
      console.log(chalk.cyanBright(title))
    },
    success: (test) => {
      console.log(chalk.greenBright('✓'), test.name)
    },
    fail: (test, e) => {
      const line = e.stack.match(/at.*:(.*):/)[1]
      lines.push(line)
      console.log(chalk.redBright('✗'), line, test.name)
    },
    end: (stats) => {
      const { success, fail, testFail } = stats
      console.log(chalk.redBright('✗ ' + fail), chalk.greenBright('✓ ' + success))

      if (testFail.length == 1) {
        console.log('Lines in error', chalk.redBright(lines))

        const stack = stackParser(testFail[0].error.stack)
        console.log(stack.diff)
      }
    }
  }

  return report
}

export { linereporter }